@@ -29,8 +29,7 @@
 #include <glib.h>
 
 #include "parole-stream.h"
-#include "parole-file.h"
-#include "enum-gtypes.h"
+#include "parole-enum-types.h"
 
 #define PAROLE_STREAM_GET_PRIVATE(o) \
 (G_TYPE_INSTANCE_GET_PRIVATE ((o), PAROLE_TYPE_STREAM, ParoleStreamPrivate))
@@ -50,6 +49,7 @@ struct _ParoleStreamPrivate
 {
     /*Properties*/
     gchar      *uri;
+    gchar      *subtitles;
     gboolean 	has_audio;
     gboolean    has_video;
     gboolean 	live;
@@ -76,6 +76,7 @@ enum
 {
     PROP_0,
     PROP_URI,
+    PROP_SUBTITLES,
     PROP_LIVE,
     PROP_MEDIA_TYPE,
     PROP_HAS_AUDIO,
@@ -121,7 +122,7 @@ parole_stream_get_media_type_from_uri (ParoleStream *stream, const gchar *uri)
     else 
 	type = PAROLE_MEDIA_TYPE_UNKNOWN;
     
-    g_value_init (&val, ENUM_GTYPE_MEDIA_TYPE);
+    g_value_init (&val, PAROLE_ENUM_TYPE_MEDIA_TYPE);
     g_value_set_enum (&val, type);
     g_object_set_property (G_OBJECT (stream), "media-type", &val);
     g_value_unset (&val);
@@ -145,6 +146,9 @@ static void parole_stream_set_property (GObject *object,
 	    parole_stream_get_media_type_from_uri (stream, priv->uri);
 	    break;
 	}
+	case PROP_SUBTITLES:
+	    PAROLE_STREAM_DUP_GVALUE_STRING (PAROLE_STREAM_GET_PRIVATE (stream)->subtitles, value);
+	    break;
 	case PROP_LIVE:
 	    PAROLE_STREAM_GET_PRIVATE (stream)->live = g_value_get_boolean (value);
 	    break;
@@ -221,6 +225,9 @@ static void parole_stream_get_property (GObject *object,
 	case PROP_URI:
 	    g_value_set_string (value, PAROLE_STREAM_GET_PRIVATE (stream)->uri);
 	    break;
+	case PROP_SUBTITLES:
+	    g_value_set_string (value, PAROLE_STREAM_GET_PRIVATE (stream)->subtitles);
+	    break;
 	case PROP_LIVE:
 	    g_value_set_boolean (value, PAROLE_STREAM_GET_PRIVATE (stream)->live);
 	    break;
@@ -316,7 +323,24 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_URI,
 				     g_param_spec_string ("uri",
-							  NULL, NULL,
+							  "Uri", 
+							  "Uri",
+							  NULL,
+							  G_PARAM_READWRITE));
+    
+    /**
+     * ParoleStream:subtitles:
+     * 
+     * Subtitles path, this is only valid if the property
+     * "media-type" has the value PAROLE_MEDIA_TYPE_LOCAL_FILE.
+     * 
+     * Since: 0.2 
+     **/
+    g_object_class_install_property (object_class,
+				     PROP_SUBTITLES,
+				     g_param_spec_string ("subtitles",
+							  "Subtitles", 
+							  "Subtitle file",
 							  NULL,
 							  G_PARAM_READWRITE));
     
@@ -330,7 +354,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_HAS_AUDIO,
 				     g_param_spec_boolean ("has-audio",
-							   NULL, NULL,
+							   "Has audio",
+							   "Has audio",
 							   FALSE,
 							   G_PARAM_READWRITE));
     /**
@@ -343,7 +368,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_HAS_VIDEO,
 				     g_param_spec_boolean ("has-video",
-							   NULL, NULL,
+							   "Has video", 
+							   "Has video",
 							   FALSE,
 							   G_PARAM_READWRITE));
     
@@ -357,22 +383,24 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_LIVE,
 				     g_param_spec_boolean ("live",
-							   NULL, NULL,
+							   "Live", 
+							   "Live",
 							   FALSE,
 							   G_PARAM_READWRITE));
 
     /**
      * ParoleStream:media-type:
      * 
-     *
+     *	The media type.
      * 
      * Since: 0.2 
      **/
     g_object_class_install_property (object_class,
 				     PROP_MEDIA_TYPE,
 				     g_param_spec_enum ("media-type",
-							NULL, NULL,
-							ENUM_GTYPE_MEDIA_TYPE,
+							"Media type", 
+							"Media type",
+							PAROLE_ENUM_TYPE_MEDIA_TYPE,
 							PAROLE_MEDIA_TYPE_UNKNOWN,
 							G_PARAM_READWRITE));
 
@@ -387,7 +415,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_SEEKABLE,
 				     g_param_spec_boolean ("seekable",
-							   NULL, NULL,
+							   "Seekable", 
+							   "Seekable",
 							   FALSE,
 							   G_PARAM_READWRITE));
 
@@ -401,7 +430,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_DURATION,
 				     g_param_spec_double("duration",
-							 NULL, NULL,
+							 "Duration", 
+							 "Duration",
 							 0, G_MAXDOUBLE,
 							 0,
 							 G_PARAM_READWRITE));
@@ -416,7 +446,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_SEEKABLE,
 				     g_param_spec_boolean ("tag-available",
-							   NULL, NULL,
+							   "Tag available",
+							   "Tag available",
 							   FALSE,
 							   G_PARAM_READWRITE));
 
@@ -430,7 +461,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_ABSOLUTE_DURATION,
 				     g_param_spec_int64 ("absolute-duration",
-							  NULL, NULL,
+							  "Absolution duration",
+							  "Absolution duration",
 							  0, G_MAXINT64,
 							  0,
 							  G_PARAM_READWRITE));
@@ -445,7 +477,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_DISP_PAR_N,
 				     g_param_spec_uint ("disp-par-n",
-							NULL, NULL,
+						        "Disp par n",
+						        "Disp par n",
 							1, G_MAXUINT,
 							1,
 							G_PARAM_READWRITE));
@@ -460,7 +493,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_DISP_PAR_D,
 				     g_param_spec_uint ("disp-par-d",
-							NULL, NULL,
+							"Disp par d",
+							"Disp par d",
 							1, G_MAXUINT,
 							1,
 							G_PARAM_READWRITE));
@@ -475,7 +509,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_VIDEO_WIDTH,
 				     g_param_spec_int    ("video-width",
-							  NULL, NULL,
+							  "Video width",
+							  "Video width",
 							  0, G_MAXINT,
 							  0,
 							  G_PARAM_READWRITE));
@@ -490,7 +525,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_VIDEO_HEIGHT,
 				     g_param_spec_int    ("video-height",
-							  NULL, NULL,
+							  "Video height",
+							  "Video height",
 							  0, G_MAXINT,
 							  0,
 							  G_PARAM_READWRITE));
@@ -506,7 +542,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_TRACKS,
 				     g_param_spec_uint   ("num-tracks",
-							  NULL, NULL,
+							  "Num tracks",
+							  "Number of tracks in the audio disc",
 							  1, 99,
 							  1,
 							  G_PARAM_READWRITE));
@@ -514,13 +551,16 @@ parole_stream_class_init (ParoleStreamClass *klass)
     /**
      * ParoleStream:track:
      * 
+     * Currently playing track, this is only valid if
+     * #ParoleStream:media-type: is PAROLE_MEDIA_TYPE_CDDA.
      * 
      * Since: 0.2 
      **/
     g_object_class_install_property (object_class,
 				     PROP_TRACK,
 				     g_param_spec_uint   ("track",
-							  NULL, NULL,
+							  "Track", 
+							  "Track",
 							  1, 99,
 							  1,
 							  G_PARAM_READWRITE));
@@ -534,7 +574,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_TITLE,
 				     g_param_spec_string ("title",
-							  NULL, NULL,
+							  "Title", 
+							  "Title",
 							  NULL,
 							  G_PARAM_READWRITE));
 
@@ -549,7 +590,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_ARTIST,
 				     g_param_spec_string ("artist",
-							  NULL, NULL,
+							  "Artist", 
+							  "Artist",
 							  NULL,
 							  G_PARAM_READWRITE));
 							  
@@ -563,7 +605,8 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_YEAR,
 				     g_param_spec_string ("year",
-							  NULL, NULL,
+							  "Year", 
+							  "Year",
 							  NULL,
 							  G_PARAM_READWRITE));
 							  
@@ -577,21 +620,23 @@ parole_stream_class_init (ParoleStreamClass *klass)
     g_object_class_install_property (object_class,
 				     PROP_ALBUM,
 				     g_param_spec_string ("album",
-							  NULL, NULL,
+							  "Album", 
+							  "Album",
 							  NULL,
 							  G_PARAM_READWRITE));
 							  
     /**
      * ParoleStream:comment:
      * 
-     * 
+     * Extra comment block.
      * 
      * Since: 0.2 
      **/
     g_object_class_install_property (object_class,
 				     PROP_COMMENT,
 				     g_param_spec_string ("comment",
-							  NULL, NULL,
+							  "Comment", 
+							  "Comment",
 							  NULL,
 							  G_PARAM_READWRITE));
 							  
@@ -635,6 +680,7 @@ void parole_stream_init_properties (ParoleStream *stream)
     
     PAROLE_STREAM_FREE_STR_PROP (priv->title);
     PAROLE_STREAM_FREE_STR_PROP (priv->uri);
+    PAROLE_STREAM_FREE_STR_PROP (priv->subtitles);
     PAROLE_STREAM_FREE_STR_PROP (priv->artist);
     PAROLE_STREAM_FREE_STR_PROP (priv->year);
     PAROLE_STREAM_FREE_STR_PROP (priv->album);
